@@ -40,7 +40,7 @@ class Device:
         definition: Dict[str, Any],
         data_properties: Optional[List[Dict[str, Any]]] = None,
         widget: Optional[str] = None,
-        ui_class: str,
+        ui_class: Optional[str] = None,
         qualified_name: Optional[str] = None,
         states: Optional[List[Dict[str, Any]]] = None,
         type: int,
@@ -70,8 +70,8 @@ class Definition:
         *,
         commands: List[Dict[str, Any]],
         states: Optional[List[Dict[str, Any]]] = None,
-        widget_name: str,
-        ui_class: str,
+        widget_name: Optional[str] = None,
+        ui_class: Optional[str] = None,
         qualified_name: str,
         **_: Any
     ) -> None:
@@ -258,6 +258,7 @@ class Scenario:
 
 
 class ProductType(Enum):
+    NONE = 0
     ACTUATOR = 1
     SENSOR = 2
     VIDEO = 3
